@@ -28,12 +28,13 @@
 
 #include <KLocalizedString>
 #include <KPluginFactory>
-#include <KIO/JobUiDelegate>
-#include <KIO/OpenUrlJob>
+#include <KPluginLoader>
+#include <KRun>
 
 #include "filemetadatawidget.h"
 
-K_PLUGIN_CLASS_WITH_JSON(BalooFilePropertiesPlugin, "baloofilepropertiesplugin.json")
+K_PLUGIN_FACTORY(BalooFilePropertiesPluginFactory, registerPlugin<BalooFilePropertiesPlugin>();)
+K_EXPORT_PLUGIN(BalooFilePropertiesPlugin("fileshare_propsdlgplugin"))
 
 BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QList<QVariant> &args)
     : KPropertiesDialogPlugin(qobject_cast<KPropertiesDialog *>(parent))
@@ -49,9 +50,7 @@ BalooFilePropertiesPlugin::BalooFilePropertiesPlugin(QObject *parent, const QLis
     auto *metaDataWidget = new Baloo::FileMetaDataWidget();
     metaDataWidget->setItems(properties->items());
     connect(metaDataWidget, &Baloo::FileMetaDataWidget::urlActivated, this, [this](const QUrl &url) {
-        KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
-        job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, properties));
-        job->start();
+        new KRun(url, properties);
     });
 
     containerLayout->addWidget(metaDataWidget);
